..
   This is an autogenerated file from processors.rst

avatars.processors.InterRecordRangeDifferenceProcessor
======================================================

.. autoclass:: avatars.processors.InterRecordRangeDifferenceProcessor
   :members: